<?php
/**
 * @package Wapple_Architect
 * @subpackage WAPL Theme
 */

/**
 * Get WAPL header
 * @return string
 */
function get_wapl_header()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'header.php';
	return include_once($file);
}

/**
 * Get WAPL footer
 * @return string
 */
function get_wapl_footer()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'footer.php';
	return include_once($file);
}
/**
 * Get comments code
 * @return string 
 */
function get_wapl_comments()
{
	$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'comments.php';
	return include_once($file);
}

/**
 * Debug function
 * @param $debug mixed
 * @access public
 * @return void
 */
if(!function_exists('debug'))
{
	function debug($debug)
	{
		echo '<pre>'.print_r($debug,true).'</pre>';
	}
}

/**
 * Process WAPL into meaningful markup
 * @param $waplString string
 * @access public
 * @return void
 */
function process_wapl($waplString)
{
	if(ARCHITECT_DO_SOAP)
	{
		global $waplHeaders;
		global $waplSoapClient;
		
		$params = array('devKey' => get_option('architect_devkey'), 'wapl' => utf8_encode($waplString), 'deviceHeaders' => $waplHeaders);
		
		// Send markup to API and parse through simplexml
		$xml = simplexml_load_string($waplSoapClient->getMarkupFromWapl($params));
		
		foreach($xml->header->item as $val)
		{
		    header($val);
		}
		echo trim($xml->markup);
	} else
	{
		header('Content-type: application/xml');
		echo $waplString;
	}
}

require_once('wapl_builder.php');
/**
 * WordPress WAPL parser
 * 
 * Extends the waplBuilder class to build perfect markup
 * @author Rich Gubby
 */
class WordPressWapl extends waplBuilder
{
	/**
	 * Format content into WAPL readable format
	 * @param string $content
	 * @param integer $imagescale
	 * @param integer $imagequality
	 * @param string $class
	 * @param integer $length
	 * @access public
	 * @return string
	 */
	function format_text($content, $imagescale = 95, $imagequality = 90, $class = 'entry', $length = null)
	{
		// Any special filters for other plugins
		$content = $this->__filters($content, $class);
		
		// Get rid of the "more" links - don't need these for mobile, they clutter things up
		preg_match_all('/<a(.*?)>(.*?)<\/a>/i', $content, $matches, PREG_OFFSET_CAPTURE);
		
		foreach($matches as $val)
		{
			foreach($val as $matchVal)
			{
				if(strpos($matchVal[0], 'class="more-link"') !== false)
				{
					$content = str_replace($matchVal[0], '', $content);
				}
			}
		}
	
		//remove all captions
		//$content = preg_replace('/(\[caption(.*?)\])(.*?)(\[\/caption\])/i', '${3}', $content);

		// Use parent format text
		$content = parent::format_text($content, $imagescale, $imagequality, $class, $length);
		
		return $content;
	}
	
	/**
	 * Special filters written specifically for other plugins
	 * @param string $content
	 * @param string $class
	 * @access public
	 * @return string
	 */
	function __filters($content, $class)
	{
		// Path to extensions
		$path = '';
		if(defined('WP_PLUGIN_DIR'))
		{
			$path = WP_PLUGIN_DIR;
		} else if(defined('ABSPATH'))
		{
			$path = ABSPATH.'wp-content'.DIRECTORY_SEPARATOR.'plugins';
		}
		$path .= DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'extensions';
		
		if ($handle = opendir($path)) 
		{
			// Get all files in the extensions directory
			while (false !== ($file = readdir($handle))) 
			{
				if ($file != '.' && $file != '..' && $file != '.svn') 
				{
					// Include the file
					include_once($path.DIRECTORY_SEPARATOR.$file);
					
					// Get class name - should match the filename
					$className = substr($file,0,strpos($file,'.'));
					
					// Create a new class
					if(class_exists($className))
					{
						$filterClass = new $className;
					
						if(method_exists($filterClass, 'format'))
						{
							// Return formatted text
							$content = $filterClass->format($content, $class);
						}
					} 
				}
			}
			closedir($handle);
		}
		return $content;
	}
}

/**
 * Load a WAPL element
 * @param $element string
 * @access public
 * @return void
 */
function get_wapl_element($element)
{
	return require('elements/'.$element.'.php');
}

function get_wapl_response_string($type, $count, $title = '')
{
	$responseFormat = array(
		1 => array(
			0 => '%d responses',
			1 => '%d response',
			2 => '%d responses'
		),
		2 => array(
			0 => '%d responses to %s',
			1 => '%d response to %s',
			2 => '%d responses to %s'
		),
		3 => array(
			0 => '%d comments',
			1 => '%d comment',
			2 => '%d comments'
		),
		4 => array(
			0 => '%d comments to %s',
			1 => '%d comment to %s',
			2 => '%d comments to %s'
		)
	);
	if($count == 0 || $count == 1)
	{
		return sprintf($responseFormat[$type][$count], $count, $title);
	} else
	{
		return sprintf($responseFormat[$type][2], $count, $title);
	}
}
?>